.. _test_ad_double-name:

!!!!!!!!!!!!!!
test_ad_double
!!!!!!!!!!!!!!

.. meta::
   :keywords: test_ad_double,run,ad_double,example,and,check,its,result,file

.. index:: test_ad_double, run, ad_double, check, its, result

.. _test_ad_double-title:

Run ad_double Example and Check its Result
##########################################

.. literalinclude:: ../../example/class.cpp
   :lines: 231-239
   :language: cpp

.. contents::
   :local:

.. _test_ad_double@Example File:

Example File
************
:ref:`class_example@This Example File`
is the same as for the parent of this page.
